@@ -16,6 +16,7 @@ __all__ = [
     "signed_angle",
     "rotate",
     "scale_factor",
+    "aligned_with",
     "orient",
     "almost_zero",
     "almost_unit_length",
@@ -379,7 +380,7 @@ def scale_factor(v1, v2):
     return v1_dot_v2 / v1_dot_v1
 
 
-def orient(vector, along, reverse=False):
+def aligned_with(vector, along, reverse=False):
     """
     Given two vectors, flip the first if necessary, so that it points
     (approximately) along the second vector rather than (approximately)
@@ -407,6 +408,19 @@ def orient(vector, along, reverse=False):
         return vector
 
 
+def orient(vector, along, reverse=False):
+    """
+    Deprecated alias for `aligned_with()`. Will be removed in v2.
+    """
+    import warnings
+
+    warnings.warn(
+        "`vg.orient()` has been deprecated and will be removed in vg 2. Use `vg.aligned_with()` instead.",
+        DeprecationWarning,
+    )
+    return aligned_with(vector, along, reverse=reverse)
+
+
 def almost_zero(v, atol=1e-08):
     """
     Test if v is almost the zero vector.
